@@ -114,9 +114,6 @@ test_that("tests work", {
   testGeneric(simulationOutput, summary = spread)
 
 
-
-  ################################################################
-
   ###### Refited ##############
 
   # if model is refitted, a different test will be called
@@ -125,58 +122,57 @@ test_that("tests work", {
   testDispersion(simulationOutput)
 
 
-  # Standard use
-  testSpatialAutocorrelation(simulationOutput, x =  testData$x, y = testData$y)
-  testSpatialAutocorrelation(simulationOutput, x =  testData$x, y = testData$y, alternative = "two.sided")
-
-  # If x and y is not provided, random values will be created
-  testSpatialAutocorrelation(simulationOutput)
-
-  # Alternatively, one can provide a distance matrix
-  dM = as.matrix(dist(cbind(testData$x, testData$y)))
-  testSpatialAutocorrelation(simulationOutput, distMat = dM)
-
-
-  # Standard use
-  testTemporalAutocorrelation(simulationOutput, time =  testData$time)
-  testTemporalAutocorrelation(simulationOutput, time =  testData$time, alternative = "greater")
-
-  # If no time is provided, random values will be created
-  testTemporalAutocorrelation(simulationOutput)
-
-  ##################################################################
-
-  # grouped
-  simulationOutput <- recalculateResiduals(simulationOutput, group = testData$group)
-
-  # if model is refitted, a different test will be called
-
-  simulationOutput <- simulateResiduals(fittedModel = fittedModel, refit = T)
-  testDispersion(simulationOutput)
-
-
-  # Standard use
-  testSpatialAutocorrelation(simulationOutput, x =  testData$x, y = testData$y)
-  testSpatialAutocorrelation(simulationOutput, x =  testData$x, y = testData$y, alternative = "two.sided")
-
-  # If x and y is not provided, random values will be created
-  testSpatialAutocorrelation(simulationOutput)
-
-  # Alternatively, one can provide a distance matrix
-  dM = as.matrix(dist(cbind(testData$x, testData$y)))
-  testSpatialAutocorrelation(simulationOutput, distMat = dM)
-
-
-  # Standard use
-  testTemporalAutocorrelation(simulationOutput, time =  testData$time)
-  testTemporalAutocorrelation(simulationOutput, time =  testData$time, alternative = "two.sided")
-
-  # If no time is provided, random values will be created
-  testTemporalAutocorrelation(simulationOutput)
 
 })
 
 
+
+###### Correlation tests #####
+
+test_that("correlation tests work", {
+  
+  testData = createData(sampleSize = 200, overdispersion = 0.5, pZeroInflation = 0, randomEffectVariance = 0)
+  fittedModel <- glm(observedResponse ~ Environment1 , family = "poisson", data = testData)
+  simulationOutput <- simulateResiduals(fittedModel = fittedModel)
+  
+  # grouped
+  simulationOutputGrouped <- recalculateResiduals(simulationOutput, group = testData$group)
+    
+  ###### testSpatialAutocorrelation #####
+
+  # Standard use
+  testSpatialAutocorrelation(simulationOutput, x =  testData$x, y = testData$y)
+  testSpatialAutocorrelation(simulationOutput, x =  testData$x, y = testData$y, alternative = "two.sided")
+  
+  # If x and y is not provided, random values will be created
+  expect_error(testSpatialAutocorrelation(simulationOutput))
+  
+  # Alternatively, one can provide a distance matrix
+  dM = as.matrix(dist(cbind(testData$x, testData$y)))
+  testSpatialAutocorrelation(simulationOutput, distMat = dM)
+  testSpatialAutocorrelation(simulationOutput, distMat = dM , alternative = "two.sided")
+  
+  # testting when x and y have different length
+  #testSpatialAutocorrelation(simulationOutput, x =  testData$x[1:10], y = testData$y[1:9] )      # Error different length  
+  #testSpatialAutocorrelation(simulationOutput[1:10], x =  testData$x[1:10], y = testData$y[1:10] ) # causing Error since x and y have equal length but unequal to simulationOutput
+  # see Issue #190  'https://github.com/florianhartig/DHARMa/issues/190' 
+  
+  # testing distance matrix and an extra x or y argument 
+  testSpatialAutocorrelation(simulationOutput, distMat = dM, x = testData$x)
+  testSpatialAutocorrelation(simulationOutput, distMat = dM, y = testData$y)
+  
+  
+  ###### testTemporalAutocorrelation #####
+  
+  # Standard use
+  testTemporalAutocorrelation(simulationOutput, time =  testData$time)
+  testTemporalAutocorrelation(simulationOutput, time =  testData$time, alternative = "greater")
+  
+  # error if time is forgotten
+  expect_error(testTemporalAutocorrelation(simulationOutput))
+
+})
+  
 # Test Outliers
 test_that("testOutliers", {
 
